@@ -121,6 +121,10 @@ class Application(ApplicationPartDelete, ApplicationPartHead,
 
     def _handle_request(self, environ: types.WSGIEnviron
                         ) -> _IntermediateResponse:
+        time_begin = datetime.datetime.now()
+        request_method = environ["REQUEST_METHOD"].upper()
+        unsafe_path = environ.get("PATH_INFO", "")
+
         """Manage a request."""
         def response(status: int, headers: types.WSGIResponseHeaders,
                      answer: Union[None, str, bytes]) -> _IntermediateResponse:
@@ -144,7 +148,8 @@ class Application(ApplicationPartDelete, ApplicationPartHead,
                     headers["Content-Encoding"] = "gzip"
 
                 headers["Content-Length"] = str(len(answer))
-                answers.append(answer)
+                if request_method != "HEAD":
+                    answers.append(answer)
 
             # Add extra headers set in configuration
             headers.update(self._extra_headers)
@@ -153,11 +158,9 @@ class Application(ApplicationPartDelete, ApplicationPartHead,
             time_end = datetime.datetime.now()
             status_text = "%d %s" % (
                 status, client.responses.get(status, "Unknown"))
-            logger.info(
-                "%s response status for %r%s in %.3f seconds: %s",
-                environ["REQUEST_METHOD"], environ.get("PATH_INFO", ""),
-                depthinfo, (time_end - time_begin).total_seconds(),
-                status_text)
+            logger.info("%s response status for %r%s in %.3f seconds: %s",
+                        request_method, unsafe_path, depthinfo,
+                        (time_end - time_begin).total_seconds(), status_text)
             # Return response content
             return status_text, list(headers.items()), answers
 
@@ -175,35 +178,25 @@ class Application(ApplicationPartDelete, ApplicationPartHead,
         depthinfo = ""
         if environ.get("HTTP_DEPTH"):
             depthinfo = " with depth %r" % environ["HTTP_DEPTH"]
-        time_begin = datetime.datetime.now()
-        logger.info(
-            "%s request for %r%s received from %s%s",
-            environ["REQUEST_METHOD"], environ.get("PATH_INFO", ""), depthinfo,
-            remote_host, remote_useragent)
+        logger.info("%s request for %r%s received from %s%s",
+                    request_method, unsafe_path, depthinfo,
+                    remote_host, remote_useragent)
         logger.debug("Request headers:\n%s",
                      pprint.pformat(self._scrub_headers(environ)))
 
-        # Let reverse proxies overwrite SCRIPT_NAME
-        if "HTTP_X_SCRIPT_NAME" in environ:
-            # script_name must be removed from PATH_INFO by the client.
-            unsafe_base_prefix = environ["HTTP_X_SCRIPT_NAME"]
-            logger.debug("Script name overwritten by client: %r",
-                         unsafe_base_prefix)
-        else:
-            # SCRIPT_NAME is already removed from PATH_INFO, according to the
-            # WSGI specification.
-            unsafe_base_prefix = environ.get("SCRIPT_NAME", "")
-        # Sanitize base prefix
-        base_prefix = pathutils.sanitize_path(unsafe_base_prefix).rstrip("/")
-        logger.debug("Sanitized script name: %r", base_prefix)
+        # SCRIPT_NAME is already removed from PATH_INFO, according to the
+        # WSGI specification.
+        # Reverse proxies can overwrite SCRIPT_NAME with X-SCRIPT-NAME header
+        base_prefix = environ.get("HTTP_X_SCRIPT_NAME",
+                                  environ.get("SCRIPT_NAME", ""))
+        logger.debug("Base prefix: %r", base_prefix)
         # Sanitize request URI (a WSGI server indicates with an empty path,
         # that the URL targets the application root without a trailing slash)
-        path = pathutils.sanitize_path(environ.get("PATH_INFO", ""))
+        path = pathutils.sanitize_path(unsafe_path)
         logger.debug("Sanitized path: %r", path)
 
         # Get function corresponding to method
-        function = getattr(
-            self, "do_%s" % environ["REQUEST_METHOD"].upper(), None)
+        function = getattr(self, "do_%s" % request_method, None)
         if not function:
             return response(*httputils.METHOD_NOT_ALLOWED)
 
